@@ -251,7 +251,6 @@ static INLINE void parse_rc_file(const char *rcfile)
 /*
  * Read the "system" configuration file, /etc/nALFSrc.
  */
-
 void read_system_rc_file(void)
 {
 	char system_rc_file[] = "/etc/nALFSrc";
@@ -262,13 +261,13 @@ void read_system_rc_file(void)
 }
 
 /*
- * Constructs a full name of configuration file and calls a parser.
+ * Read the "user" configuration file, ~/.nALFSrc.
  */
 void read_user_rc_file(void)
 {
 	char *home_dir;
 	char *rcfile;
-
+	struct stat st;
 
 	home_dir = get_home_directory();
 
@@ -281,7 +280,8 @@ void read_user_rc_file(void)
 	append_str(&rcfile, "/");
 	append_str(&rcfile, RC_FILE_NAME);
 
-	parse_rc_file(rcfile);
+	if (!stat(rcfile, &st))
+		parse_rc_file(rcfile);
 
 	xfree(rcfile);
 }
