@@ -24,10 +24,17 @@
 #ifndef H_INIT_
 #define H_INIT_
 
+/*
+ * Some program's info.
+ */
+#define EMAIL              "haski@sezampro.yu"
+#define SITE               "http://www.linuxfromscratch.org/alfs/"
+#define COPYRIGHT          "Copyright (C) 2001-2003 Neven Has"
 
 void read_env_variables(void);
 
-int read_rc_file(void);
+void read_system_rc_file(void);
+void read_user_rc_file(void);
 
 void read_command_line_options(int *argc, char ***argv);
 
